<?php

namespace App\Http\Controllers\Admin\Score;

use App\Http\Controllers\Controller;
use App\Repositories\Enums\ResponseCodeEnum;
use Illuminate\Http\Request;

use Jiannei\Response\Laravel\Support\Facades\Response;
use Prettus\Validator\Contracts\ValidatorInterface;
use App\Contracts\Repositories\Score\MemberRepository;
use App\Repositories\Validators\Score\MemberValidator;

/**
 * Class MembersController.
 *
 * @package namespace App\Http\Controllers\Score;
 */
class MembersController extends Controller
{
    /**
     * @var MemberRepository
     */
    protected $repository;

    /**
     * @var MemberValidator
     */
    protected $validator;

    /**
     * MembersController constructor.
     *
     * @param MemberRepository $repository
     * @param MemberValidator $validator
     */
    public function __construct(MemberRepository $repository, MemberValidator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
    }

    public function index(Request $request)
    {
        $lists = $this->repository->paginate(request('per_page', self::PAGE_NUM));

        return Response::success($lists);
    }


    public function store(Request $request)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_CREATE));
        try {
            $model = $this->repository->create($request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_CREATE))));
            return Response::success($model);
        } catch (\Exception $e) {
            return $this->errorStore($e);
        }
    }

    public function show($id)
    {
        $model = $this->repository->find($id);
        return Response::success($model);
    }


    public function update(Request $request, $id)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_UPDATE));

        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_CREATE)));
            $model = $this->repository->update($data, $id);
            return Response::success($model);
        } catch (\Exception $e) {
            $this->errorStore($e);
        }
    }

    public function destroy($id)
    {
        try {
            $re = $this->repository->delete($id);
            if ($re) {
                return Response::success(null, T('successfully delete.'));
            } else {
                return Response::fail(T('Prohibit to delete.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
            }
        } catch (\Exception $exception) {
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        }
    }

    public function lists(Request $request)
    {
        $lists = $this->repository->scopeQuery(function ($query) {
            return $query->limit(10);
        })->all();
        return Response::success($lists);
    }

    public function getTagsSelectOptions(Request $request)
    {
        $lists = $this->repository->skipPresenter()->pluck('tags')->flatMap(function ($values) {
            return $values;
        })->unique()->all();
        return Response::success($lists);
    }
}
