<?php

namespace App\Http\Controllers\Admin\Score;

use App\Http\Controllers\Controller;
use App\Repositories\Enums\ResponseCodeEnum;
use App\Repositories\Models\Score\Category;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use Prettus\Validator\Contracts\ValidatorInterface;
use App\Contracts\Repositories\Score\RecordRepository;
use App\Repositories\Validators\Score\RecordValidator;

/**
 * Class RecordsController.
 *
 * @package namespace App\Http\Controllers\Score;
 */
class RecordsController extends Controller
{
    /**
     * @var RecordRepository
     */
    protected $repository;

    /**
     * @var RecordValidator
     */
    protected $validator;

    /**
     * RecordsController constructor.
     *
     * @param RecordRepository $repository
     * @param RecordValidator $validator
     */
    public function __construct(RecordRepository $repository, RecordValidator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
    }


    public function index(Request $request)
    {
        $lists = $this->repository->paginate(request('per_page', self::PAGE_NUM));

        return Response::success($lists);
    }

    public function lists()
    {
        $lists = $this->repository->all();

        return Response::success($lists);
    }


    public function store(Request $request)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_CREATE));

        if ($request->get('type') == 0) {
            $max = Category::query()->where('id', 6)->value('value');
            $min = Category::query()->where('id', 5)->value('value');
            $val = $request->get('score');
            if ($val < $min || $max < $val) {
                return Response::fail("兑换的积分必须在{$min}~{$max}之间");
            }
        }

        try {
            $bill = $this->repository->create($request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_CREATE))));
            return Response::success($bill);
        } catch (\Exception $e) {
            return $this->errorStore($e);
        }
    }


    public function show($id)
    {
        $model = $this->repository->find($id);
        return Response::success($model);
    }


    public function update(Request $request, $id)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_UPDATE));

        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_CREATE)));
            $model = $this->repository->update($data, $id);
            return Response::success($model);
        } catch (\Exception $e) {
            $this->errorStore($e);
        }
    }

    public function destroy($id)
    {
        try {
            $re = $this->repository->delete($id);
            if ($re) {
                return Response::success(null, T('successfully delete.'));
            } else {
                return Response::fail(T('Prohibit to delete.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
            }
        } catch (\Exception $exception) {
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        }
    }
}
