<?php

namespace App\Http\Controllers\Api\Base;

use App\Exports\StaffsExport;
use App\Http\Controllers\Controller;
use App\Http\Resources\ResourceResource;
use App\Repositories\Enums\ResponseCodeEnum;
use App\Repositories\Models\Resource;
use App\Services\ResourceService;
use Illuminate\Http\Request;

use App\Http\Requests;
use Illuminate\Support\Facades\Storage;
use Jiannei\Response\Laravel\Support\Facades\Response;
use Prettus\Validator\Contracts\ValidatorInterface;
use Prettus\Validator\Exceptions\ValidatorException;
use App\Http\Requests\ResourceCreateRequest;
use App\Http\Requests\ResourceUpdateRequest;
use App\Contracts\Repositories\ResourceRepository;
use App\Repositories\Validators\ResourceValidator;

/**
 * Class ResourcesController.
 *
 * @package namespace App\Http\Controllers;
 */
class ResourceController extends Controller
{
    private $resourceService;

    public function __construct(ResourceService $resourceService)
    {
        $this->resourceService = $resourceService;
    }

    public function upload(Request $request)
    {
        $this->validate($request, [
            'file' => 'file',
            'type' => 'required',
            'file_type' => 'required|in:img,file'
        ]);
        $re = $this->resourceService->handleUpload($request);
        if ($re === false) {
            return Response::fail(T('Error uploading file.'), ResponseCodeEnum::SERVICE_UPLOAD_ERROR);
        }
        return Response::success(new ResourceResource($re));
    }


    /**
     * 导出
     * Author: Mead
     */
    public function download(Request $request)
    {
        $this->validate($request, ['id' => 'required|integer']);
        $resource = Resource::query()->first($request->get('id'));
        return response()->download(Storage::disk($resource->disk)->url($resource->path));
    }
}
