<?php

namespace App\Repositories\Criteria\Score;

use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class RecordCriteria.
 *
 * @package namespace App\Repositories\Criteria\Score;
 */
class RecordCriteria implements CriteriaInterface
{
    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }

    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($name = $this->request->get('name')) {
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if (($status = $this->request->get('status', false)) !== false) {
            $model = $model->where('status', '=', $status);
        }

        if ($mobile = $this->request->get('mobile')) {
            $model = $model->whereHas('member', function ($query) use ($mobile) {
                return $query->where('mobile', 'like', "%{$mobile}%");
            });
        }

        if ($member_id = $this->request->get('member_id')) {
            $model = $model->where('member_id', '=', $member_id);
        }

        if ($day = $this->request->get('day')) {
            $model = $model->whereDate('created_at', '=', $day);
        }

        if ($time = $this->request->get('time')) {
            $model = $model->whereDate('created_at', '>=', $time[0])->whereDate('created_at', '<=', $time[1]);
        }

        if ($id = $this->request->get('id')) {
            $model = $model->where('id', '=', $id);
        }

        $model = $model->orderByDesc('id');
        return $model;
    }
}
