<?php

namespace App\Repositories\Models\Score;

use App\Repositories\Enums\Score\RecordTypeEnum;
use App\Repositories\Models\Model;
use Prettus\Repository\Contracts\Transformable;
use Prettus\Repository\Traits\TransformableTrait;

/**
 * Class Record.
 *
 * @package namespace App\Repositories\Models\Score;
 */
class Record extends Model implements Transformable
{
    use TransformableTrait;


    protected $table = 'score_records';

    protected static function booted()
    {
        //创建前
        static::creating(function (Record $record) {
            $record->admin_id = login_admin_id();
            switch ($record->type) {
                case RecordTypeEnum::IN:
                    $v = Category::query()->where('id', 3)->value('value');
                    $record->score = bcmul($record->money, $v / 100, 0);
                    break;
                case RecordTypeEnum::OUT:
                    $v = Category::query()->where('id', 4)->value('value');
                    $record->money = bcmul($record->score, $v / 100, 0);
                    $record->score = -abs($record->score);
                    break;
            }
        });

        static::created(function (Record $record) {
            switch ($record->type) {
                case RecordTypeEnum::IN:
                    Member::query()->where('id', $record->member_id)->increment('score', $record->score);
                    Member::query()->where('id', $record->member_id)->increment('total_score', $record->score);
                    break;
                case RecordTypeEnum::OUT:
                    Member::query()->where('id', $record->member_id)->increment('score', $record->score);
                    break;
            }
        });
    }

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $guarded = [];

    public function member()
    {
        return $this->belongsTo(Member::class)->select(['id', 'name', 'mobile']);
    }

}
